import json
import os
from dotenv import load_dotenv, set_key
from .api import generate_keys
from .utils import check_env_exists

def ask_questions():
    user_data = {}
    user_data['name'] = input("What is your name? ")
    user_data['age'] = input("What is your age? ")
    user_data['color'] = input("What color do you like? ")
    user_data['email'] = input("What is your email address? ")
    return user_data

def save_to_json(data, filename='user_data.json'):
    with open(filename, 'w') as f:
        json.dump(data, f)

def main():
    if not check_env_exists():
        user_data = ask_questions()
        save_to_json(user_data)

        response = generate_keys(user_data)
        
        if response:
            app_key, company_key = response['application_key'], response['company_key']
        else:
            app_key, company_key = '', ''
            print("No response from server. Keys will be empty.")

        load_dotenv()
        set_key('.env', 'APPLICATION_KEY', app_key)
        set_key('.env', 'COMPANY_KEY', company_key)
        
        print("Keys have been saved to .env file.")
    else:
        print(".env file already exists. No need to run the setup again.")


import requests

API_URL = "https://mask-keys-server.onrender.com/generate-mask-keys-for-user"

def generate_keys(user_data):
    try:
        response = requests.post(API_URL, json=user_data)
        response.raise_for_status()
        return response.json()
    except requests.exceptions.RequestException as e:
        print(f"Error: {e}")
        return None


from setuptools import setup, find_packages
from setuptools.command.install import install
import subprocess

class PostInstallCommand(install):
    def run(self):
        install.run(self)
        subprocess.run(["mask-key"])

setup(
    name='mask_key',
    version='0.2.1',
    author='krishna agarwal',
    author_email='krishnacool781@gmail.com',
    description='A Python package to generate mask keys.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/krishnaagarwal781/mask_keys_server',
    packages=find_packages(),
    install_requires=[
        'requests',
        'python-dotenv',
    ],
    entry_points={
        'console_scripts': [
            'mask-key=mask_key.main:main',
        ],
    },
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    cmdclass={
        'install': PostInstallCommand,
    }
)
